Index: sys/dev/sound/isa/mss.c
===================================================================
RCS file: /usr/cvs/src/sys/dev/sound/isa/mss.c,v
retrieving revision 1.48
diff -u -r1.48 mss.c
--- sys/dev/sound/isa/mss.c	2000/03/05 15:51:09	1.48
+++ sys/dev/sound/isa/mss.c	2000/03/08 16:38:13
@@ -32,6 +32,7 @@
 
 /* board-specific include files */
 #include <dev/sound/isa/mss.h>
+#include <dev/sound/isa/sb.h>
 #include <dev/sound/chip.h>
 
 #include "gusc.h"
@@ -1329,6 +1330,27 @@
     	return 0;
 }
 
+static int
+azt2320_mss_mode(struct mss_info *mss, device_t dev)
+{
+	struct resource *sbport;
+
+	/* XXX: works because mss->io_rid == 0 here */
+	sbport = bus_alloc_resource(dev, SYS_RES_IOPORT, &mss->io_rid,
+				    0, ~0, 1, RF_ACTIVE);
+	if (sbport)
+	{
+		while (port_rd(sbport, SBDSP_STATUS) & 0x80);
+		port_wr(sbport, SBDSP_CMD, 0x09);
+		while (port_rd(sbport, SBDSP_STATUS) & 0x80);
+		port_wr(sbport, SBDSP_CMD, 0x00);
+		DELAY(1000);
+		bus_release_resource(dev, SYS_RES_IOPORT, mss->io_rid, sbport);
+		return 0;
+	}
+	else return -1;
+}
+
 static struct isa_pnp_id pnpmss_ids[] = {
 	{0x0000630e, "CS423x"},				/* CSC0000 */
 	{0x0001630e, "CS423x-PCI"},			/* CSC0100 */
@@ -1338,6 +1360,7 @@
 	{0x1093143e, "OPTi931"},			/* OPT9310 */
 	{0x5092143e, "OPTi925"},			/* OPT9250 XXX guess */
 	{0x1022b839, "Neomagic 256AV (non-ac97)"},	/* NMX2210 */
+	{0x20235407, "Aztech 2320"},			/* AZT2320 */
 #if 0
 	{0x0000561e, "GusPnP"},				/* GRV0000 */
 #endif
@@ -1348,11 +1371,13 @@
 pnpmss_probe(device_t dev)
 {
 	u_int32_t lid, vid;
-
+	
 	lid = isa_get_logicalid(dev);
 	vid = isa_get_vendorid(dev);
 	if (lid == 0x01000000 && vid != 0x0100a90d) /* CMI0001 */
 		return ENXIO;
+	if (lid == 0x01005407)			    /* AZT0001 */
+		return 0;
 	return ISA_PNP_PROBE(device_get_parent(dev), dev, pnpmss_ids);
 }
 
@@ -1407,6 +1432,15 @@
 	    mss->bd_id = MD_CS42XX;
 	    break;
 
+	case 0x01005407:			/* AZT0001 */
+	    /* put into MSS mode first (snatched from NetBSD) */
+	    if (azt2320_mss_mode(mss, dev))
+	    	return ENXIO;
+
+	    mss->bd_flags |= BD_F_MSS_OFFSET;
+	    mss->io_rid = 2;
+	    break;
+	    
 #if 0
 	case 0x0000561e:			/* GRV0000 */
 	    mss->bd_flags |= BD_F_MSS_OFFSET;

